------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_BagSpace.lua - Triggered on full bags
--
-- Author: Expelliarm5s / August 2022 / All Rights Reserved
--
-- Version 1.1.17
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI BACKPACK_CONTAINER GetContainerItemID

local addonName, addon = ...
local modle = addon:NewModule("BagSpace", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
------------------------------------------------------------------------------

function modle:ModuleName()
	return modle.moduleName
end

function modle:ToggleMod()
	addon.db.global[modle.moduleName] = addon.db.global[modle.moduleName] or false
	addon.db.global[modle.moduleName] = not addon.db.global[modle.moduleName]
	if addon.db.global[modle.moduleName] then
		addon:Printf(L["Module %s enabled"], modle.moduleName)
	else
		addon:Printf(L["Module %s disabled"], modle.moduleName)
	end
end

function modle:EnableMod()
	addon.db.global[modle.moduleName] = true
	addon:Printf(L["Module %s enabled"], modle.moduleName)
end

function modle:DisableMod()
	addon.db.global[modle.moduleName] = false
	addon:Printf(L["Module %s disabled"], modle.moduleName)
end

function modle:Login()
	if not tonumber(addon.db.global.BagSpaceSlots) then
		addon.db.global.BagSpaceSlots = "2"
	end

	modle:RegisterEvent("LOOT_OPENED")
end

function modle:ModuleIcon()
	return "INTERFACE\\ICONS\\INV_Misc_Bag_09_Red"
end

function modle:TriggerName()
	return L["Bags full!"]
end

function modle:TriggerDesc()
	return L["Alarm fires on full bags."]
end

function modle:GetItemID(val)
	if type(val) == "number" then
		return val
	end

	if type(val) == "string" then
		local id = val:match("item:([0-9]+)")
		if id and tonumber(id) then
			return tonumber(id)
		end
	end
end

function modle:GetOptions()
	local options = {
		type = "input",
		name = L["Free Bag Slots:"],
		desc = L["Number of free bags lots left to trigger an alarm, e.g. \"2\"."],
		width = "full",
		get = function(info)
			return addon.db.global.BagSpaceSlots
		end,
		set = function(info, value)
			if value then
				if tonumber(value) then
					addon.db.global.BagSpaceSlots = value
				else
					addon.db.global.BagSpaceSlots = "2"
				end
			end
		end,
	}
	return options
end

function modle:LOOT_OPENED(event)
	addon:DebugPrintf(modle.moduleName .. "~  %s", tostring(event))
	if event == "LOOT_OPENED" then
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			local freeSlots = 0
			for bagID = BACKPACK_CONTAINER, NUM_BAG_SLOTS do
				local bagSize = GetContainerNumSlots(bagID)
				for slot = 1, bagSize do
					local bagItemID = GetContainerItemID(bagID, slot)
					if not bagItemID then
						freeSlots = freeSlots + 1
					end
				end
			end

			local doAlarm = false
			if tonumber(addon.db.global.BagSpaceSlots) and tonumber(addon.db.global.BagSpaceSlots) > 0 and tonumber(addon.db.global.BagSpaceSlots) < 800 then
				if freeSlots <= tonumber(addon.db.global.BagSpaceSlots) then
					doAlarm = true
				end
			end

			addon:DebugPrintf(modle.moduleName .. "~  %s free slots", tostring(freeSlots))

			if doAlarm then
				addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
				addon:Printf(format(L["Module %s: %s (%s or less slots left)"], modle.moduleName, modle:TriggerName(), tostring(addon.db.global.BagSpaceSlots)))
				if addon.GUI.Fire then
					addon.GUI:Fire(modle.moduleName)
				end
			end
		end
	end
end

-- EOF